-- ----------------------------
-- 证照目录模板表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_certificate_catalog_template`;
CREATE TABLE `mortals_xhx_certificate_catalog_template` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '序号，主键，自增长',
  `siteId` bigint(20) DEFAULT NULL COMMENT '站点id',
  `catalogId` bigint(20) NOT NULL COMMENT '目录id',
  `templateName` varchar(128) DEFAULT NULL COMMENT '证照模板名称',
  `templateType` tinyint(2) DEFAULT '0' COMMENT '模板类型1普通2正本3副本',
  `templateFileName` varchar(128) DEFAULT NULL COMMENT '证照模板文件名称',
  `templateFileUrl` varchar(128) DEFAULT NULL COMMENT '证照模板文件地址',
  `formContent` text COMMENT '证照模板表单内容',
  `exampleFileUrl` varchar(128) DEFAULT NULL COMMENT '证照示例图地址',
  `status` tinyint(2) DEFAULT '1' COMMENT '证照状态，0：禁用1：启用',
  `excelFile` varchar(128) DEFAULT NULL COMMENT '批量导入模板文件地址',
  `isPdf` tinyint(2) DEFAULT '0' COMMENT '是否生成PDF，0：否1：是',
  `deviceId` bigint(20) DEFAULT NULL COMMENT '打印设备Id',
  `printerName` varchar(128) DEFAULT NULL COMMENT '打印机名称',
  `printerIp` varchar(128) DEFAULT NULL COMMENT '打印机网络地址',
  `paperSource` varchar(128) DEFAULT NULL COMMENT '打印机纸盒',
  `createUserId` bigint(20) DEFAULT NULL COMMENT '创建用户',
  `createTime` datetime DEFAULT NULL COMMENT '创建时间',
  `updateUserId` bigint(20) DEFAULT NULL COMMENT '更新用户',
  `updateTime` datetime DEFAULT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='证照目录模板';


ALTER TABLE `mortals_xhx_certificate_catalog` 
 DROP COLUMN `templateName`,
 DROP COLUMN `templateUrl`,
 DROP COLUMN `formContent`,
 DROP COLUMN `exampleUrl`,
 DROP COLUMN `excelFile`,
 DROP COLUMN `isPdf`,
 DROP COLUMN `deviceId`,
 DROP COLUMN `printerName`,
 DROP COLUMN `printerIp`,
 DROP COLUMN `paperSource`;


ALTER TABLE `mortals_xhx_apply_log`
 ADD COLUMN `templateId` bigint(20) DEFAULT NULL COMMENT '证照目录模板ID' AFTER `catalogName`,
 ADD COLUMN `templateName` varchar(128) DEFAULT NULL COMMENT '证照模板名称' AFTER `templateId`;

ALTER TABLE `mortals_xhx_print_wait_queue`
 ADD COLUMN `templateId` bigint(20) DEFAULT NULL COMMENT '证照目录模板ID' AFTER `catalogName`,
 ADD COLUMN `templateName` varchar(128) DEFAULT NULL COMMENT '证照模板名称' AFTER `templateId`;

ALTER TABLE `mortals_xhx_retain_log`
 ADD COLUMN `templateId` bigint(20) DEFAULT NULL COMMENT '证照目录模板ID' AFTER `catalogName`,
 ADD COLUMN `templateName` varchar(128) DEFAULT NULL COMMENT '证照模板名称' AFTER `templateId`;

ALTER TABLE `mortals_xhx_print_log`
 ADD COLUMN `templateId` bigint(20) DEFAULT NULL COMMENT '证照目录模板ID' AFTER `catalogName`,
 ADD COLUMN `templateName` varchar(128) DEFAULT NULL COMMENT '证照模板名称' AFTER `templateId`;

ALTER TABLE `mortals_xhx_print_catalog`
 ADD COLUMN `templateId` bigint(20) DEFAULT NULL COMMENT '证照目录模板ID' AFTER `catalogName`,
 ADD COLUMN `templateName` varchar(128) DEFAULT NULL COMMENT '证照模板名称' AFTER `templateId`;

ALTER TABLE `mortals_xhx_apply_log` ADD COLUMN `mobile` varchar(64) DEFAULT NULL  COMMENT '手机号码';
ALTER TABLE `mortals_xhx_print_wait_queue` ADD COLUMN `mobile` varchar(64) DEFAULT NULL  COMMENT '手机号码';
ALTER TABLE `mortals_xhx_retain_log` ADD COLUMN `mobile` varchar(64) DEFAULT NULL  COMMENT '手机号码';
ALTER TABLE `mortals_xhx_print_log` ADD COLUMN `mobile` varchar(64) DEFAULT NULL  COMMENT '手机号码';





-- ----------------------------
-- 角色权限改造 2025-04-23
-- ----------------------------
-- ----------------------------
-- 资源信息业务表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_resource`;
CREATE TABLE mortals_xhx_resource(
     `id` bigint(20)   AUTO_INCREMENT   COMMENT '菜单ID，主键，自增长',
     `name` varchar(50)      COMMENT '名称',
     `groupName` varchar(255)      COMMENT '分组名称',
     `url` varchar(2000)      COMMENT '连接地址，多个地址以逗号分隔',
     `authType` tinyint(2)    DEFAULT '3'  COMMENT '权限类型 (0.无限制，1.无需登录查看，2.需要登录查看，3.需要角色权限查看)',
     `sourceType` tinyint(2)    DEFAULT '0'  COMMENT '资源类型，(0.系统资源，1.开放资源)',
     `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
     `createUserName` varchar(50)      COMMENT '创建用户名称',
     `createTime` datetime NOT NULL     COMMENT '创建时间',
     `updateUserId` bigint(20)      COMMENT '更新用户',
     `updateUserName` varchar(50)      COMMENT '创建用户名称',
     `updateTime` datetime      COMMENT '更新时间',
     PRIMARY KEY  (`id`),
     INDEX `idx_name`(`name`) USING BTREE,
     INDEX `idx_groupName`(`groupName`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='资源信息业务';


-- ----------------------------
-- 角色信息业务表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_role`;
CREATE TABLE mortals_xhx_role(
     `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
     `name` varchar(50)      COMMENT '角色名称',
     `remark` varchar(200)      COMMENT '备注',
     `roleType` tinyint(2)    DEFAULT '2'  COMMENT '角色类型 (0.系统内置角色,1.默认系统角色.2.普通角色)',
     `customerId` bigint(20)      COMMENT '归属客户ID',
     `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
     `createUserName` varchar(50)      COMMENT '创建用户名称',
     `createTime` datetime NOT NULL     COMMENT '创建时间',
     `updateUserId` bigint(20)      COMMENT '更新用户',
     `updateUserName` varchar(50)      COMMENT '创建用户名称',
     `updateTime` datetime      COMMENT '更新时间',
     PRIMARY KEY  (`id`),
     INDEX `idx_name`(`name`) USING BTREE,
     INDEX `idx_roleType`(`roleType`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='角色信息业务';

-- ----------------------------
-- 角色资源权限业务表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_role_auth`;
CREATE TABLE mortals_xhx_role_auth(
  `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
  `roleId` bigint(20)      COMMENT '角色ID',
  `menuId` bigint(20)      COMMENT '菜单ID',
  `resourceId` bigint(20)      COMMENT '资源ID',
  `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
  `createUserName` varchar(50)      COMMENT '创建用户名称',
  `createTime` datetime NOT NULL     COMMENT '创建时间',
  `updateUserId` bigint(20)      COMMENT '更新用户',
  `updateUserName` varchar(50)      COMMENT '创建用户名称',
  `updateTime` datetime      COMMENT '更新时间',
  PRIMARY KEY  (`id`),
  INDEX `idx_roleId`(`roleId`) USING BTREE,
  INDEX `idx_menuId`(`menuId`) USING BTREE,
  INDEX `resourceId` (`resourceId`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='角色资源权限业务';


-- ----------------------------
-- 角色用户业务表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_role_user`;
CREATE TABLE mortals_xhx_role_user(
  `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
  `roleId` bigint(20)      COMMENT '角色ID',
  `userId` bigint(20)      COMMENT '用户ID',
  `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
  `createUserName` varchar(50)      COMMENT '创建用户名称',
  `createTime` datetime NOT NULL     COMMENT '创建时间',
  `updateUserId` bigint(20)      COMMENT '更新用户',
  `updateUserName` varchar(50)      COMMENT '创建用户名称',
  `updateTime` datetime      COMMENT '更新时间',
  PRIMARY KEY  (`id`),
  INDEX `idx_roleId`(`roleId`) USING BTREE,
  INDEX `idx_userId`(`userId`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='角色用户业务';

DROP TABLE IF EXISTS `mortals_xhx_menu`;
CREATE TABLE mortals_xhx_menu(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '菜单ID，主键，自增长',
    `name` varchar(50)      COMMENT '菜单名称',
    `url` varchar(256)      COMMENT '路由地址',
    `ancestors` varchar(255)      COMMENT '当前节点父id路径，“，”分割',
    `parentId` bigint(20)      COMMENT '父菜单ID，一级菜单的该字段值为-1',
    `linkType` tinyint(2)    DEFAULT '0'  COMMENT '链接方式 (0.普通，1.弹出，2.脚本)',
    `imgPath` varchar(128)      COMMENT '主菜单图标，主菜单图标的css样式名',
    `buttonImgPath` varchar(128)      COMMENT '按钮图标，按钮图标的css样式名',
    `imgCommPath` varchar(128)      COMMENT '常用菜单图标，常用菜单图标的css样式名',
    `commMenu` tinyint(2)    DEFAULT '1'  COMMENT '是否常用菜单 (0.非常用，1.常用)',
    `component` varchar(128)      COMMENT 'vue组件路径',
    `menuType` tinyint(2)    DEFAULT '0'  COMMENT '菜单类型 (0.目录，1.菜单，2.按钮)',
    `authType` tinyint(2)    DEFAULT '3'  COMMENT '权限类型 (0.无限制，1.无需登录查看，2.需要登录查看，3.需要角色权限查看)',
    `visible` tinyint(2)    DEFAULT '0'  COMMENT '菜单显示状态 (0.显示，1.隐藏)',
    `perms` varchar(128)      COMMENT '权限标识，多个逗号分割',
    `orderId` int(4)      COMMENT '排序编号',
    `status` tinyint(2)    DEFAULT '1'  COMMENT '菜单状态 (0.停用，1.启用)',
    `cache` tinyint(2)    DEFAULT '0'  COMMENT '是否启用缓存 (0.否，1.是)',
    `activeDir` varchar(128)      COMMENT '激活目录',
    `resourceUrl` varchar(512)      COMMENT '资源访问路径，多个逗号分割',
    `hideChildrenInMenu` tinyint(2)    DEFAULT '0'  COMMENT '是否隐藏(0.否，1.是)',
    `remark` varchar(512)      COMMENT '备注信息',
    `createTime` datetime      COMMENT '创建时间',
    `createUserId` bigint(20)      COMMENT '创建用户',
    `createUserName` varchar(50)      COMMENT '创建用户名称',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateUserName` varchar(50)      COMMENT '创建用户名称',
    `updateTime` datetime      COMMENT '更新时间',
     PRIMARY KEY  (`id`),
    INDEX `idx_name`(`name`) USING BTREE,
    INDEX `idx_url`(`url`) USING BTREE,
    INDEX `idx_parentId`(`parentId`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='菜单信息业务';


ALTER TABLE mortals_xhx_param ADD COLUMN   `updateUserId` bigint(20)      COMMENT '更新用户';
ALTER TABLE mortals_xhx_param ADD COLUMN    `updateUserName` varchar(50)      COMMENT '创建用户名称';
ALTER TABLE mortals_xhx_param ADD COLUMN    `updateTime` datetime      COMMENT '更新时间';